Struct ariadne::ReportBuilder [−][src]
pub struct ReportBuilder<S: Span> { /* fields omitted */ }
A type used to build a Report.
Implementations
Give this report a numerical code that may be used to more precisely look up the error in documentation.
Give this report a message.
Add a new label to the diagnostic.
Use the given Config to determine diagnostic attributes.